@@ -202,6 +202,7 @@ class Trinket:
             200563: Source.RARE_MOB,  # Primal Ritual Shell
             200859: Source.RARE_MOB,  # Seasoned Hunter's Trophy
             198407: Source.WORLD_QUEST,  # Azure Arcanic Amplifier
+            198542: Source.WORLD_QUEST,  # Shikaari Huntress' Arrowhead
         }
 
         if self.item_id in item_mapping.keys():
@@ -269,7 +270,7 @@ class Trinket:
                 levels += ItemLevel.ITEM_LEVELS[self.source][season]  # type: ignore
 
             elif self.source == Source.WORLD_QUEST:
-                levels = ItemLevel.ITEM_LEVELS[self.source][season] # type: ignore
+                levels = ItemLevel.ITEM_LEVELS[self.source][season]  # type: ignore
 
             elif self.source == Source.PROFESSION:
                 levels += ItemLevel.ITEM_LEVELS[self.source][season]  # type: ignore
@@ -278,8 +279,6 @@ class Trinket:
                     levels = [level for level in levels if level < epic_cutoff]
                 elif "Darkmoon Deck Box:" in self.full_name:
                     levels = [level for level in levels if level >= epic_cutoff]
-                elif "Idol of the" in self.full_name:
-                    levels = [level for level in levels if level < epic_cutoff]
 
             elif self.source == Source.WORLD_BOSS:
                 # is REPLACED by prepared itemlevels, blizzard hotfixes are hot fixes
@@ -461,7 +460,10 @@ class Trinket:
             if self.source == Source.RARE_MOB:
                 return [Season.SEASON_1]
 
-            if self.item_id in (198407,):
+            if self.item_id in (
+                198407,
+                198542,
+            ):
                 return [Season.SEASON_1]
         # TODO: add more logic to present more trinkets as season trinkets
 
